% ----------------------
% TE.m
% ----------------------
% computes the temporary equilibrium for the global time 't'
% in:   -
% out:  edy
% ----------------------

function edyresid = TE(interest)

global t rho sigma
global Y Div w I V K H Omega C edy  r
global A_0 alpha L0 delta

r(t+1)  = interest;

% PRODUCTION AND INVESTMENT
Y(t)    = A_0*K(t)^alpha*L0^(1-alpha);
w(t)    = (1-alpha)*Y(t)/L0;
r(t)    = alpha*Y(t)/K(t)-delta;
I(t)    = V(t+1)/(1+r(t+1))-(1-delta)*K(t);
Div(t)  = Y(t)-w(t)*L0-I(t);
K(t+1)  = I(t)+(1-delta)*K(t);
V(t)    = Div(t)+V(t+1)/(1+r(t+1));

% CONSUMPTION AND SAVINGS
H(t)    = w(t)*L0+H(t+1)/(1+r(t+1));
Omega(t)= 1 + (1/(1+rho))^sigma*(1+r(t+1))^(sigma-1)*Omega(t+1);
C(t)    = (H(t)+V(t))/Omega(t);

% EQUILIBRIUM
edy(t)  = I(t)+C(t)-Y(t);
edyresid = edy(t);

end

